pub struct GetMaintenanceWindowExecutionTaskInvocationRequest {
pub invocation_id: String,
pub task_id: String,
pub window_execution_id: String,
}Fields
invocation_id: StringThe invocation ID to retrieve.
task_id: StringThe ID of the specific task in the maintenance window task that should be retrieved.
window_execution_id: StringThe ID of the maintenance window execution for which the task is a part.