pub enum RegisterTaskWithMaintenanceWindowError {
DoesNotExist(String),
FeatureNotAvailable(String),
IdempotentParameterMismatch(String),
InternalServerError(String),
ResourceLimitExceeded(String),
}Expand description
Errors returned by RegisterTaskWithMaintenanceWindow
Variants
DoesNotExist(String)
Error returned when the ID specified for a resource, such as a maintenance window or Patch baseline, doesn't exist.
For information about resource quotas in Systems Manager, see Systems Manager service quotas in the AWS General Reference.
FeatureNotAvailable(String)
You attempted to register a LAMBDA or STEP_FUNCTIONS task in a region where the corresponding service is not available.
IdempotentParameterMismatch(String)
Error returned when an idempotent operation is retried and the parameters don't match the original call to the API with the same idempotency token.
InternalServerError(String)
An error occurred on the server side.
ResourceLimitExceeded(String)
Error returned when the caller has exceeded the default resource quotas. For example, too many maintenance windows or patch baselines have been created.
For information about resource quotas in Systems Manager, see Systems Manager service quotas in the AWS General Reference.
Implementations